@@ -56,6 +56,8 @@ def write_template(template_path, template_source):
         os.makedirs(base_dir)
     with tempfile.NamedTemporaryFile(
             mode='w+t', dir=base_dir, delete=False) as temp_file:
+        if six.PY2 and hasattr(template_source, 'encode'):
+            template_source = template_source.encode('utf-8')
         temp_file.write(template_source)
     os.rename(temp_file.name, template_path)
     LOGGER.info("pid %d wrote to %s", os.getpid(), template_path)
@@ -178,6 +180,8 @@ class SourceEditAPIView(ThemePackageMixin, UpdateEditableMixin,
             LOGGER.info("searching for %s in %s ...", element_id, template_path)
             with open(template_path) as template_file:
                 template_string = template_file.read()
+                if six.PY2 and hasattr(template_string, 'decode'):
+                    template_string = template_string.decode('utf-8')
             try:
                 template_string = force_str(template_string)
                 engine, unused_libraries, unused_builtins = get_html_engine()
@@ -443,6 +447,8 @@ class SourceDetailAPIView(ThemePackageMixin, generics.RetrieveUpdateAPIView,
         with open(get_template_path(
                 relative_path=relative_path)) as source_file:
             source_content = source_file.read()
+            if six.PY2 and hasattr(source_content, 'decode'):
+                source_content = source_content.decode('utf-8')
         return Response({'path': relative_path, 'text': source_content})
 
     def update(self, request, *args, **kwargs):
